@@ -125,7 +125,8 @@ runtest($a, 'msin', $a_msin);
 runtest($a_mcos, 'macos', pdl([[1.7018092, 0.093001244],[0.26737858,1.8645614]]));
 runtest($a_msin, 'masin', pdl([[-1.4397834,0.093001244],[0.26737858,-1.2770313]]));
 runtest($a, 'morth', pdl([-0.762586,-0.646886],[-0.646886,0.762586]));
-runtest($rank2, 'mnull', pdl(-0.751304,0.319700,0.577350)->t);
+my $mnull_soln = pdl(-0.751304,0.319700,0.577350)->t;
+runtest($rank2, 'mnull', [$mnull_soln, [pdl(-0.751304,0.319700,-0.577350)->t,$mnull_soln]]);
 runtest($a, 'mpinv', pdl([0.463087,-0.511014],[0.0678448,-0.201667]));
 runtest($a, 'mlu', pdl([1,0],[0.184782,1]));
 runtest($wide->t, 'mlu', pdl([1,0],[0.042857,1],[0.614285,0.881526]));
